RutubeWebConfig class

Configuration for Rutube web player

Constructors

RutubeWebConfig({PlatformViewHitTestBehavior hitTestBehavior = PlatformViewHitTestBehavior.opaque, Object? creationParams})
Creates configuration for Rutube web player.
const

Properties

creationParams Object?
Creation params to pass to the platform view.
final
hashCode int
The hash code for this object.
no setterinherited
hitTestBehavior PlatformViewHitTestBehavior
The hit test behavior for the platform view.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited