RutubeMobileConfig class
Configuration for Rutube mobile player
Constructors
- RutubeMobileConfig({InAppWebViewSettings? initialSettings, WebViewConsoleMessageCallback? onConsoleMessage, WebViewLoadStopCallback? onLoadStop, bool showConsoleMessages = false})
-
Creates configuration for Rutube mobile player.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialSettings → InAppWebViewSettings?
-
Initial WebView settings. If null, default settings will be used.
final
- onConsoleMessage → WebViewConsoleMessageCallback?
-
Callback for WebView console messages.
final
- onLoadStop → WebViewLoadStopCallback?
-
Callback for when page finishes loading.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showConsoleMessages → bool
-
Whether to print console messages to debug log.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited